@@ -46,7 +46,7 @@ class Check:
 
         self.config: BaseConfig = config
         self.encoding = config.settings["encoding"]
-        self.cz = factory.commiter_factory(self.config)
+        self.cz = factory.committer_factory(self.config)
 
     def _valid_command_argument(self):
         num_exclusive_args_provided = sum(
@@ -72,7 +72,7 @@ class Check:
             raise NoCommitsFoundError(f"No commit found with range: '{self.rev_range}'")
 
         pattern = self.cz.schema_pattern()
-        ill_formated_commits = [
+        ill_formatted_commits = [
             commit
             for commit in commits
             if not self.validate_commit_message(commit.message, pattern)
@@ -80,7 +80,7 @@ class Check:
         displayed_msgs_content = "\n".join(
             [
                 f'commit "{commit.rev}": "{commit.message}"'
-                for commit in ill_formated_commits
+                for commit in ill_formatted_commits
             ]
         )
         if displayed_msgs_content:
